@@ -364,6 +364,7 @@ where
     #[serde(deserialize_with = "http_method::deserialize_optional")]
     #[serde(serialize_with = "http_method::serialize_optional")]
     #[serde(skip_serializing_if = "Option::is_none")]
+    #[serde(default)]
     pub http_method: Option<Method>,
     #[serde(deserialize_with = "deserialize_headers", default)]
     #[serde(serialize_with = "serialize_headers")]
@@ -424,6 +425,7 @@ where
     #[serde(deserialize_with = "http_method::deserialize_optional")]
     #[serde(serialize_with = "http_method::serialize_optional")]
     #[serde(skip_serializing_if = "Option::is_none")]
+    #[serde(default)]
     pub http_method: Option<Method>,
     /// The API Gateway rest API Id
     #[serde(deserialize_with = "deserialize_lambda_string")]
@@ -841,4 +843,17 @@ mod test {
         let reparsed: ApiGatewayProxyRequest = serde_json::from_slice(output.as_bytes()).unwrap();
         assert_eq!(parsed, reparsed);
     }
+
+    #[test]
+    #[cfg(feature = "apigw")]
+    fn example_apigw_websocket_request_without_method() {
+        let data = include_bytes!(
+            "../generated/fixtures/example-apigw-websocket-request-without-method.json"
+        );
+        let parsed: ApiGatewayWebsocketProxyRequest = serde_json::from_slice(data).unwrap();
+        let output: String = serde_json::to_string(&parsed).unwrap();
+        let reparsed: ApiGatewayWebsocketProxyRequest =
+            serde_json::from_slice(output.as_bytes()).unwrap();
+        assert_eq!(parsed, reparsed);
+    }
 }
